#
# spec file for package ghc-deriving-compat
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name deriving-compat
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.3.6
Release:        8.9
Summary:        Backports of GHC deriving extensions
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-ghc-boot-th-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-tagged-devel
%endif

%description
Provides Template Haskell functions that mimic deriving extensions that were
introduced or modified in recent versions of GHC. Currently, the following
typeclasses/extensions are covered:

* Deriving 'Bounded'

* Deriving 'Enum'

* Deriving 'Ix'

* Deriving 'Eq', 'Eq1', and 'Eq2'

* Deriving 'Ord', 'Ord1', and 'Ord2'

* Deriving 'Read', 'Read1', and 'Read2'

* Deriving 'Show', 'Show1', and 'Show2'

* 'DeriveFoldable'

* 'DeriveFunctor'

* 'DeriveTraversable'

See the "Data.Deriving" module for a full list of backported changes.

Note that some recent GHC typeclasses/extensions are not covered by this
package:

* 'DeriveDataTypeable'

* 'DeriveGeneric', which was introducted in GHC 7.2 for deriving 'Generic'
instances, and modified in GHC 7.6 to allow derivation of 'Generic1' instances.
Use 'Generics.Deriving.TH' from
'<http://hackage.haskell.org/package/generic-deriving generic-deriving>' to
derive 'Generic(1)' using Template Haskell.

* 'DeriveLift', which was introduced in GHC 8.0 for deriving 'Lift' instances.
Use 'Language.Haskell.TH.Lift' from
'<http://hackage.haskell.org/package/th-lift th-lift>' to derive 'Lift' using
Template Haskell.

* The 'Bifunctor' typeclass, which was introduced in GHC 7.10, as well as the
'Bifoldable' and 'Bitraversable' typeclasses, which were introduced in GHC 8.2.
Use 'Data.Bifunctor.TH' from '<http://hackage.haskell.org/package/bifunctors
bifunctors>' to derive these typeclasses using Template Haskell.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 0.3.6 with cabal2obs.
* Mon Dec 19 2016 psimons@suse.com
- Update to version 0.3.5 with cabal2obs.
* Thu Oct 27 2016 psimons@suse.com
- Update to version 0.3.4 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.3.3 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.2 revision 0 with cabal2obs.
